export const a52004 = {
  number: '0x04',
  title: 'Heating Radiator Valve Actuating Drive with Feed and Room Temperature Measurement, Local Set Point Control and Display',
  status: 'released',
  description: '\n            <br/>\n            <br/>\n            <span style="border-bottom:2px groove #000000;">Description</span>\n            <br/>The following document describes the communication between a controller\n            and an intelligent heating radiator valve actuating drive with the following features:\n            <ul>\n            <li>Feed temperature measurement</li>\n            <br/>\n            <li>Room temperature measurement</li>\n            <br/>\n            <li>Current position feedback</li>\n            <br/>\n            <li>Display</li>\n            <br/>\n            <li>Button</li>\n            <br/>\n            <li>On device temperature set point selection</li>\n            <br/>\n            </ul>\n            In order to be able to process this information and control the actuator,\n            every command has been included in this document. Each customer can use\n            his own controller by implementing the EEP of this document.\n            <br/>\n            <br/>\n            <span style="border-bottom:2px groove #000000;">Data exchange</span>\n            <br/>Direction: bidirectional\n            <br/>Addressing: unicast (ADT)\n            <br/>Communication trigger: event- & time-triggered\n            <br/>Communication interval: can be configured by the controller\n            <br/>Trigger event: a trigger event occurs when the button is pressed\n            or the local set point is used\n            <br/>Tx delay: 550 ms is the maximum response time for Smart-Ack Devices\n            and 1100 ms for devices which use the 4BS teach-in method\n            <br/>Rx timeout: just 1 message per wake-up cycle\n            <br/>\n            <br/>\n            <span style="border-bottom:2px groove #000000;">Teach-in</span>\n            <br/>Teach-in method: Smart-Ack teach-in and 4BS teach-in Variation 3\n            <br/>\n            <br/>\n            <span style="border-bottom:2px groove #000000;">Security</span>\n            <br/>Encryption supported: no\n            <br/>Security level format: -\n            <br/>\n            <br/>\n            <span style="border-bottom:2px groove #000000;">Telegram Description of Direction 1</span>\n            (Transmit mode / Message from the actuator to the controller)\n            <br/>\n            <br/>\n            This direction initializes the communication, shares the needed\n            data and waits for an answer from the controller.\n            This allows the device to work in deep sleep mode the rest of the time.\n            <br/>\n            <br/>Each message from the actuator contains the following information:\n            <ul>\n            <li>Current Position (CP)\n            <br/>The current position is a feedback value from the actuator.\n            It indicates the actual per cent position of the valve.\n            The value 0 % means that the valve is completely closed and 100 %\n            completely open. The controller can use this information for the room\n            temperature regulation.</li>\n            </ul>\n            <ul><li>Temperature Set Point OR Feed Temperature (FTS)*\n            <br/>\n            * This byte is shared by the Temperature Set Point and the Feed\n            Temperature value. Only one of these values is sent in the same message.\n            Which value is transmitted is indicated by DB0.1 (TS bit).\n            <br/>\n            The feed temperature is the water temperature in the radiator input,\n            which can be useful for implementing several features in the home\n            automation system.\n            <br/>\n            The temperature set point is only sent when the user specifies a new\n            room temperature by using the local temperature set point on the device.\n            </li></ul>\n            <ul><li>Room Temperature (TMP) OR Failure Code (FC)*\n            <br/>\n            * This byte is shared by the Room Temperature and Failure Code Value.\n            Only one of these values is sent in the same message.\n            The value transmitted is indicated by DB0.0 (FL).\n            By default it is the room temperature.\n            <br/>\n            The room temperature is the ambient temperature of the place in which\n            the device is used and is measured by the actuator.\n            This value is transmitted if no error occurred.\n            <br/>\n            The Failure Code is transmitted instead of the Room Temperature\n            if an error occurs.\n            </li></ul>\n            <ul><li>Measurement Status (MST)\n            <br/>\n            The temperature measurements (room and feed temperature) can be\n            deactivated in order to reduce the energy consumption.\n            This can be specified only by the controller i.e. to implement\n            summer mode or to replace the internal room temperature measurement\n            of the actuator by an external one.\n            </li></ul>\n            <ul><li>Status Request (SRT)\n            <br/>\n            The status request bit can be used to ask the controller about its\n            status. If the controller does not send back the correct reply, the\n            actuator will start its own room temperature regulation.\n            With this feature, a frozen actuator would not interrupt the room\n            temperature regulation.\n            </li></ul>\n            <ul><li>Teach-in Bit (LRNB)\n            <br/>\n            For establishing the radio link between the controller and the actuator,\n            a teachin message has to be sent from the actuator to the controller.\n            If the binary value 0 is transmitted, the message will be identified\n            as a teach-in one and will allow the controller to receive the\n            EnOcean-ID of the actuator.\n            </li></ul>\n            <ul><li>Button Lock Status (BLS)\n            <br/>\n            The button lock status can be set by the controller. This enables or\n            disables the manual room temperature selection. If locked, the manual\n            room temperature selection on the actuator will be disabled and the\n            user will be notified with a symbol on the display.\n            </li></ul>\n            <ul><li>Temperature Selection (TS)\n            <br/>\n            If the user specifies a temperature set point manually on the device,\n            this will be sent to the controller and indicated on the temperature\n            selection field (TS). It can indicate that the field FTS contains the\n            temperature set point (binary value = 1) or the feed temperature\n            (binary value = 0).\n            </li></ul>\n            <ul><li>Failure (FL)\n            <br/>\n            Indicates the occurrence of a failure. The room temperature value is\n            replaced by the failure code if the bit FL has the binary value 1.\n            </li></ul>\n            <br/>\n            <span style="border-bottom:2px groove #000000;">Telegram Description of Direction 2</span>\n            (Receive mode / Commands from the controller to the actuator)\n            <br/>\n            <br/>\n            The messages from the controller to the actuator are sent in this direction.\n            A message in this direction has to be sent after receiving a message from\n            the actuator, in order to achieve a successful communication.\n            If the controller message is not received by the actuator in a specific\n            time after a direction 1 message, no information will be received by\n            the actuator. The time that the actuator will wait for a reply is defined\n            by the Smart-Ack Teach-In process. For controllers which cannot use\n            Smart-Ack, the 4BS Teach-in Variation 3 has to be used, with a maximum\n            response time of 1100 ms.\n            <br/>\n            <br/>Each message from the controller contains the following information:\n            <ul><li>\n            Valve Position (POS)\n            <br/>\n            The valve position is a set point position for the valve.\n            It indicates the per cent position of the valve, which the actuator\n            has to reach. The value 0 % means that the valve is completely closed\n            and 100 % completely open. The controller should be able to regulate\n            the room temperature by adjusting this value.\n            </li></ul>\n            <ul><li>\n            Temperature Set Point (TSP)\n            <br/>\n            The controller can send the temperature set point to the actuator in\n            order to allow the user to see the actual specified temperature in\n            the device display. This value does not affect room temperature regulation.\n            </li></ul>\n            <ul><li>\n            Measurement Control (MC)\n            <br/>\n            The temperature measurements (room and feed temperature) can be\n            deactivated in order to reduce energy consumption. This can be specified\n            only by the controller i.e. to implement summer mode or to replace\n            the internal room temperature measurement by the device with an\n            external one. The measurement control bit enables the controller to\n            activate or deactivate the measurements.\n            </li></ul>\n            <ul><li>\n            Wake-up Cycle (WUC)\n            <br/>\n            To save energy, the actuator works in deep sleep mode the most of the\n            time. Nevertheless it has to wake up to communicate with the controller\n            and to reach the valve position specified by the controller.\n            The longer the actuator remains in deep sleep mode, the more energy\n            efficient will be your batteries. If fast response is required, the\n            actuator has to communicate more frequently with the controller and\n            that is why it should use a shorter wake-up cycle. If a fast room\n            temperature control is not required, the wake-up cycle should be set\n            by the controller as long as possible.\n            </li></ul>\n            <ul><li>\n            Display Orientation (DSO)\n            <br/>\n            The heater valves can be installed in different directions.\n            That is why it can be useful to have the option to choose the fitting\n            display orientation. This feature makes reading the display easier.\n            </li></ul>\n            <ul><li>\n            Teach-in Bit (LRNB)\n            <br/>\n            For establishing a radio link between the controller and the actuator,\n            a teach-in telegram has to be sent from the controller to the actuator.\n            If the binary value 0 is transmitted, the message will be identified\n            as a teach-in one and will allow the device to receive the EnOcean-ID\n            from the controller.\n            </li></ul>\n            <ul><li>\n            Button Lock Control (BLS)\n            <br/>\n            The button lock status can be set by the controller. This enables or\n            disables the manual room temperature selection. If locked, the manual\n            room temperature selection on the actuator will be disabled and the\n            user will be notified with a symbol on the display.\n            </li></ul>\n            <ul><li>\n            Service Command (SER)\n            <br/>\n            In order to adapt the actuator to a new valve, the controller can\n            order the execution of some functions of the actuator:\n            <br/>\n            - run initialisation: This function has to be executed for adapting\n            the actuator to the length of the valve stroke.\n            <br/>\n            - open valve: To facilitate the installation or maintenance of the\n            valve, the actuator can open the valve completely.\n            After completely opening the valve it is necessary to run the initialisation.\n            <br/>\n            - close valve: Completely close the valve.\n            </li></ul>',
  case: [{
    direction: '1',
    condition: {
      direction: '1'
    },
    datafield: [{
      reserved: {},
      bitoffs: '26',
      bitsize: '2'
    }, {
      data: 'LRN Bit',
      shortcut: 'LRNB',
      description: 'LRN Bit',
      bitoffs: '28',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Teach-in telegram'
        }, {
          value: '1',
          description: 'Data telegram'
        }]
      }
    }, {
      data: 'Current Position',
      shortcut: 'CP',
      description: 'Current valve position',
      info: '',
      bitoffs: '0',
      bitsize: '8',
      range: {
        min: '0',
        max: '100'
      },
      scale: {
        min: '0',
        max: '100'
      },
      unit: '%'
    }, {
      data: 'Feed Temperature OR Temperature Set Point',
      shortcut: 'FTS',
      description: 'Either current feed temperature value or temperature\n              set point (defined by DB0.1)',
      info: '',
      bitoffs: '8',
      bitsize: '8',
      range: {
        min: '0',
        max: '255'
      },
      scale: {
        min: '20 .. 80',
        max: '10 .. 30'
      },
      unit: '°C'
    }, {
      data: 'Room Temperature OR Failure Code',
      shortcut: 'TMPFC',
      description: 'Current room temperature value (10...30°C) OR Failure Code (Enum)',
      info: {},
      bitoffs: '16',
      bitsize: '8',
      enum: {
        item: [{
          min: '0',
          max: '255',
          scale: {
            min: '10',
            max: '30'
          },
          unit: '°C'
        }, {
          value: '00 ... 16',
          description: 'Reserved'
        }, {
          value: '17',
          description: 'Measurement error'
        }, {
          value: '18',
          description: 'Battery empty'
        }, {
          value: '19',
          description: 'Reserved'
        }, {
          value: '20',
          description: 'Frost protection'
        }, {
          value: '21 ... 32',
          description: 'Reserved'
        }, {
          value: '33',
          description: 'Blocked valve'
        }, {
          value: '34 ... 35',
          description: 'Reserved'
        }, {
          value: '36',
          description: 'End point detection error'
        }, {
          value: '37 ... 39',
          description: 'Reserved'
        }, {
          value: '40',
          description: 'No valve'
        }, {
          value: '41 ... 48',
          description: 'Reserved'
        }, {
          value: '49',
          description: 'Not taught in'
        }, {
          value: '50 ... 52',
          description: 'Reserved'
        }, {
          value: '53',
          description: 'No response from controller'
        }, {
          value: '54',
          description: 'Teach-in error'
        }, {
          value: '55 ... 255',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Measurement Status',
      shortcut: 'MST',
      description: 'Shows if the temperature measurement (feed temperature\n              and room temperature) is active',
      bitoffs: '24',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Active'
        }, {
          value: '1',
          description: 'Inactive'
        }]
      }
    }, {
      data: 'Status Request',
      shortcut: 'STR',
      description: 'Request for status from the controller',
      bitoffs: '25',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'No change'
        }, {
          value: '1',
          description: 'Status requested'
        }]
      }
    }, {
      data: 'Button Lock Status',
      shortcut: 'BLS',
      description: 'Shows if all buttons on the actuator are locked',
      bitoffs: '29',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Unlocked'
        }, {
          value: '1',
          description: 'Locked'
        }]
      }
    }, {
      data: 'Temperature Selection',
      shortcut: 'TS',
      description: 'Defines which temperature value is transmitted in DB2',
      bitoffs: '30',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Feed temperature'
        }, {
          value: '1',
          description: 'Temperature set point'
        }]
      }
    }, {
      data: 'Failure',
      shortcut: 'FL',
      description: 'A failure occurred, see DB1.7-DB1.0 for Failure Code',
      bitoffs: '31',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'No failure (TMP is transmitted)'
        }, {
          value: '1',
          description: 'failure (FC is transmitted)'
        }]
      }
    }]
  }, {
    direction: '2',
    condition: {
      direction: '2'
    },
    datafield: [{
      reserved: {},
      bitoffs: '16',
      bitsize: '1'
    }, {
      reserved: {},
      bitoffs: '24',
      bitsize: '2'
    }, {
      data: 'Valve Position',
      shortcut: 'POS',
      description: 'Valve position',
      info: {},
      bitoffs: '0',
      bitsize: '8',
      range: {
        min: '0',
        max: '100'
      },
      scale: {
        min: '0',
        max: '100'
      },
      unit: '%'
    }, {
      data: 'Temperature Set Point',
      shortcut: 'TSP',
      description: 'Temperature set point',
      info: {},
      bitoffs: '8',
      bitsize: '8',
      range: {
        min: '0',
        max: '255'
      },
      scale: {
        min: '10',
        max: '30'
      },
      unit: '°C'
    }, {
      data: 'LRN Bit',
      shortcut: 'LRNB',
      description: 'LRN Bit',
      bitoffs: '28',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Teach-in telegram'
        }, {
          value: '1',
          description: 'Data telegram'
        }]
      }
    }, {
      data: 'Measurement Control',
      shortcut: 'MC',
      description: 'Control the temperature measurement (feed temperature\n              + room temperature)',
      bitoffs: '17',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Enable'
        }, {
          value: '1',
          description: 'Disable'
        }]
      }
    }, {
      data: 'Wake-up Cycle',
      shortcut: 'WUC',
      description: 'Defines the cyclic wake-up time',
      bitoffs: '18',
      bitsize: '6',
      enum: {
        item: [{
          value: '0',
          description: '10 sec'
        }, {
          value: '1',
          description: '60 sec'
        }, {
          value: '2',
          description: '90 sec'
        }, {
          value: '3',
          description: '120 sec'
        }, {
          value: '4',
          description: '150 sec'
        }, {
          value: '5',
          description: '180 sec'
        }, {
          value: '6',
          description: '210 sec'
        }, {
          value: '7',
          description: '240 sec'
        }, {
          value: '8',
          description: '270 sec'
        }, {
          value: '9',
          description: '300 sec (5 min)'
        }, {
          value: '10',
          description: '330 sec'
        }, {
          value: '11',
          description: '360 sec'
        }, {
          value: '12',
          description: '390 sec'
        }, {
          value: '13',
          description: '420 sec'
        }, {
          value: '14',
          description: '450 sec'
        }, {
          value: '15',
          description: '480 sec'
        }, {
          value: '16',
          description: '510 sec'
        }, {
          value: '17',
          description: '540 sec'
        }, {
          value: '18',
          description: '570 sec'
        }, {
          value: '19',
          description: '600 sec (10 min)'
        }, {
          value: '20',
          description: '630 sec'
        }, {
          value: '21',
          description: '660 sec'
        }, {
          value: '22',
          description: '690 sec'
        }, {
          value: '23',
          description: '720 sec'
        }, {
          value: '24',
          description: '750 sec'
        }, {
          value: '25',
          description: '780 sec'
        }, {
          value: '26',
          description: '810 sec'
        }, {
          value: '27',
          description: '840 sec'
        }, {
          value: '28',
          description: '870 sec'
        }, {
          value: '29',
          description: '900 sec (15 min)'
        }, {
          value: '30',
          description: '930 sec'
        }, {
          value: '31',
          description: '960 sec'
        }, {
          value: '32',
          description: '990 sec'
        }, {
          value: '33',
          description: '1020 sec'
        }, {
          value: '34',
          description: '1050 sec'
        }, {
          value: '35',
          description: '1080 sec'
        }, {
          value: '36',
          description: '1110 sec'
        }, {
          value: '37',
          description: '1140 sec'
        }, {
          value: '38',
          description: '1170 sec'
        }, {
          value: '39',
          description: '1200 sec (20 min)'
        }, {
          value: '40',
          description: '1230 sec'
        }, {
          value: '41',
          description: '1260 sec'
        }, {
          value: '42',
          description: '1290 sec'
        }, {
          value: '43',
          description: '1320 sec'
        }, {
          value: '44',
          description: '1350 sec'
        }, {
          value: '45',
          description: '1380 sec'
        }, {
          value: '46',
          description: '1410 sec'
        }, {
          value: '47',
          description: '1440 sec'
        }, {
          value: '48',
          description: '1470 sec'
        }, {
          value: '49',
          description: '1500 sec (25 min)'
        }, {
          value: '50',
          description: '3 hrs'
        }, {
          value: '51',
          description: '6 hrs'
        }, {
          value: '52',
          description: '9 hrs'
        }, {
          value: '53',
          description: '12 hrs'
        }, {
          value: '54',
          description: '15 hrs'
        }, {
          value: '55',
          description: '18 hrs'
        }, {
          value: '56',
          description: '21 hrs'
        }, {
          value: '57',
          description: '24 hrs'
        }, {
          value: '58',
          description: '27 hrs'
        }, {
          value: '59',
          description: '30 hrs'
        }, {
          value: '60',
          description: '33 hrs'
        }, {
          value: '61',
          description: '36 hrs'
        }, {
          value: '62',
          description: '39 hrs'
        }, {
          value: '63',
          description: '42 hrs (max)'
        }]
      }
    }, {
      data: 'Display Orientation',
      shortcut: 'DSO',
      description: 'Adjusts the display orientation',
      bitoffs: '26',
      bitsize: '2',
      enum: {
        item: [{
          value: '0',
          description: '0°'
        }, {
          value: '1',
          description: '90°'
        }, {
          value: '2',
          description: '180°'
        }, {
          value: '3',
          description: '270°'
        }]
      }
    }, {
      data: 'Button Lock Control',
      shortcut: 'BLC',
      description: 'Set the button lock status',
      bitoffs: '29',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Unlocked'
        }, {
          value: '1',
          description: 'Locked'
        }]
      }
    }, {
      data: 'Service Command',
      shortcut: 'SER',
      description: 'Initiates certain temporary service operations',
      bitoffs: '30',
      bitsize: '2',
      enum: {
        item: [{
          value: '0',
          description: 'No change'
        }, {
          value: '1',
          description: 'Open valve'
        }, {
          value: '2',
          description: 'Run initialisation'
        }, {
          value: '3',
          description: 'Close valve'
        }]
      }
    }]
  }],
  originalIndex: 125,
  eep: 'a5-20-04',
  rorg_title: '4BS Telegram',
  rorg_number: '0xA5',
  func_title: 'HVAC Components',
  func_number: '0x20',
  submitter: [
    'Holter Regelarmaturen GmbH & Co. KG'
  ]
}
