export const a53701 = {
  number: '0x01',
  title: 'Demand Response',
  status: 'released',
  description: '<br/><br/>\n          Purpose of EEP:<br/>\nDemand Response is a developing standard to allow utility\ncompanies to send requests for reduction in power consumption\nduring peak usage times. It is also used as a means to allow users\nto reduce overall power consumption as energy prices increase.\nHaving an EEP for this will allow ease of integration with\nEnOcean products to this standard. The EEP was designed with a\nvery flexible setting for the level (0-15) as well as a default level\nwhereby the transmitter can specify a specific level for all\ncontrollers to use (0-100% of either maximum or current power\noutput, depending on the load type). This EEP also includes a\ntimeout setting to indicate how long the DR event should last if the\nDR transmitting device does not send heartbeats or subsequent\nnew DR levels.\n<br/>\n<br/>\nDescription:\n<br/>\nThis EEP is included under a new function of Energy\nManagement. Additional types could be added in future for power,\nvoltage, and current data. The proposed EEP type 01 only deals\nwith demand response activation at this point.\nData Byte 3 is the default DR value for devices that\nimplement a control algorithm that uses a set-point. It will be used\nfor any controllers not supporting the current DR Level in the\nmessage and having an adjustable set-point.\n<br/>\n<br/>\nData Byte 2 is the default DR Level for any controllers not\nsupporting the current DR Level in the message and having an\nadjustable control. It can be defined as either a percentage of the\nmaximum power or a percentage of the current power, depending\non the value of bit 7 in Data Byte 2. Bits 0 through 6 contain the\npercentage of power (either relative or absolute) that should be\nused. A value of 0 corresponds to 0% and a value of 100\ncorresponds to 100%. Any value higher that n100 should be\ninterpreted as 100%. For example, if the current DR level is not\nsupported by the controller and Data Byte 2 bit 7 is 0 and Data\nByte 2 bits 0 through 6 are set to 55, then the controller should try\nto use 55% of its maximum power usage. In the case of a lighting\nload with 0-10V dimming, this would correspond to 5.5V on the\ndimming line. In the case of a heating controller with a maximum\nset back of 5 degrees C, this would correspond to a set back of 2.75\ndegrees C (this would most likely be rounded to 3).\n<br/>\n<br/>\nData Byte 1 is the timeout for this DR event. After this\ncommand is sent the controller will stay at the DR level for Data\nByte 1 multiplied by 15 minutes. Once this time has elapsed the\ncontroller will return to normal operation. If Data Byte 1 is 0 then\nthe controller will remain in the DR event until the next DR\ncommand is received. This timeout allows DR devices to leave or\nturn off after setting controllers into a DR state, thus the DR\ntransmitter is not needed to take the devices out of the DR state\nand the controllers will automatically recover. For example a DR\ntransmitter that only sends messages when a DR event is active\ncould be used with the timeout to create a successful DR system.\n<br/>\n<br/>\nData Byte 0, Bits 7 through 4 make up a nibble that will be\nused as the DR level. Levels 0 through 15 will be possible using\nthese bits. Bit 4 will be the lowest bit in this nibble and bit 7 will\nbe the highest. If any level is not supported by a controller then\nthat controller should use the default settings sent in this message\nor map the level to one that it supports.\n<br/>\n<br/>\nData Byte 0 Bits 2 and 1 indicate whether the power adjustment at\nstart and end of the DR event should be randomized or not. This\nfeature is intended to minimize rapid changes on the power\ndistribution equipment by delaying each controller’s response. If\nrandom start or end is enabled, each controller will delay starting\nor ending the DR event by a random time that will vary uniformly\nover a specific time period (for example, 5 seconds, 60 seconds, or\n15 minutes).. The maximum length of these random delays will\ndepend on the implementation in the controller.\n<br/>\n<br/>\nData Byte 0, Bit 0 is the state for loads that are not adjustable\nfor the default DR level. If a controller does not support the current\nDR level and does not have adjustable control then it should use\nthis bit. The two states of this bit are defined as follows: 1 =\nmaximum power usage by controller, 0 = minimum power usage\nby the controller. If for example lights are being controlled, then a\nsetting of 1 will mean the lights should be ON, where as a setting\nof 0 will mean the lights should be OFF. For a thermostat\napplication with non adjustable set back, a setting of 1 will mean\nthat no set back should be applied, whereas a setting of 0 will mean\nthat the full set back should be applied. This setting only applies to\nthe maximum power usage of the controller, if for example the\nlights are currently off and the controller receives a DR event with this bit set, then the lights should not turn ON as the DR event has\nonly set the maximum power usage for the device.',
  case: [{
    datafield: [{
      data: 'DR Level',
      shortcut: 'DRL',
      description: 'DR Level',
      bitoffs: '24',
      bitsize: '4',
      range: {
        min: '0',
        max: '15'
      },
      scale: {
        min: '0',
        max: '15'
      },
      unit: 'N/A'
    }, {
      data: 'LRN Bit',
      shortcut: 'LRNB',
      description: 'LRN Bit',
      bitoffs: '28',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Teach-in telegram'
        }, {
          value: '1',
          description: 'Data telegram'
        }]
      }
    }, {
      data: 'Temporary default',
      shortcut: 'TMPD',
      description: 'New Temporary default DR set point Min. ... Max. (linear)',
      info: 'DB_3: new Temporary default DR set-point',
      bitoffs: '0',
      bitsize: '8',
      range: {
        min: '0',
        max: '255'
      },
      scale: {
        min: '0',
        max: '255'
      },
      unit: 'N/A'
    }, {
      data: 'Absolute/relative power usage',
      shortcut: 'SPWRU',
      description: {},
      info: {},
      bitoffs: '8',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Absolute power usage. Interpret\nDB_2.BIT_6...DB_2.BIT_0 as a percentage of the\nmaximum power use.'
        }, {
          value: '1',
          description: 'Relative power usage. Interpret\nDB_2.BIT_6...DB_2.BIT_0 as a percentage of the\ncurrent power use.'
        }]
      }
    }, {
      data: 'Power Usage',
      shortcut: 'PWRU',
      description: '0% to 100% power usage in 1% increments; 101...127 = interpreted as 100%',
      info: {},
      bitoffs: '9',
      bitsize: '7',
      range: {
        min: '0',
        max: '100'
      },
      scale: {
        min: '0',
        max: '100'
      },
      unit: 'N/A'
    }, {
      data: 'Timeout Setting',
      shortcut: 'TMOS',
      description: 'Time in 15 min. intervals; 0 = No time specified; 1...255 = increasing 15 min. intervals. Max value: 3825 = 255*15',
      info: {},
      bitoffs: '16',
      bitsize: '8',
      range: {
        min: '1',
        max: '255'
      },
      scale: {
        min: '15',
        max: '3825'
      },
      unit: 'min'
    }, {
      data: 'Random start delay',
      shortcut: 'RSD',
      description: '...',
      info: {},
      bitoffs: '29',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'False'
        }, {
          value: '1',
          description: 'True'
        }]
      }
    }, {
      data: 'Randomized end delay',
      shortcut: 'RED',
      description: '...',
      info: {},
      bitoffs: '30',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'False'
        }, {
          value: '1',
          description: 'True'
        }]
      }
    }, {
      data: 'Max/Min Power Usage for Default DR State',
      shortcut: 'MPWRU',
      description: {},
      info: {},
      bitoffs: '31',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Minimum Power usage'
        }, {
          value: '1',
          description: 'Maximum Power usage'
        }]
      }
    }]
  }],
  originalIndex: 134,
  eep: 'a5-37-01',
  rorg_title: '4BS Telegram',
  rorg_number: '0xA5',
  func_title: 'Energy Management',
  func_number: '0x37',
  submitter: [
    'Echoflex Solutions Inc.'
  ]
}
