export const d20100 = {
  number: '0x00',
  title: 'Type 0x00',
  status: 'released',
  description: '',
  case: [{
    title: 'CMD 0x1 - Actuator Set Output',
    description: 'This message is sent to an actuator. It controls switching / dimming of one or all channels of an actuator.\n\t\t\t<br/><br/>\n            <img>graphics/EEP_D2-01-xx_CMD_01.png</img>\n            <br/>\n   \t\t\tREMARK:<br/>\n            In case an Actuator Set Output message specifies a parameter that is not supported by the device being addresses, such device shall react as following:<br/>\n            - channel not supported by device -> ignore message<br/>\n            - dimming command to switching device -> no change of status<br/>\n            - dimming command with non supported speed -> dim with regular speed<br/>\n            <br/>\n            RECOMMENDATION:<br/>\n            Dimmers should take things like phase shifting into account to provide\n            dimming based on power consumption (results in brightness for lamps) rather than\n            interpreting percentage values as phase angle only.\n            <br/>\n            <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x01'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x01',
          description: 'ID 01'
        }
      }
    }, {
      data: 'Dim value',
      shortcut: 'DV',
      description: {},
      info: {},
      bitoffs: '8',
      bitsize: '3',
      enum: {
        item: [{
          value: '0x00',
          description: 'Switch to new output value'
        }, {
          value: '0x01',
          description: 'Dim to new output value – dim timer 1'
        }, {
          value: '0x02',
          description: 'Dim to new output value – dim timer 2'
        }, {
          value: '0x03',
          description: 'Dim to new output value – dim timer 3'
        }, {
          value: '0x04',
          description: 'Stop dimming'
        }, {
          min: '0x05',
          max: '0x07',
          description: 'not used'
        }]
      }
    }, {
      data: 'I/O channel',
      shortcut: 'I/O',
      description: {},
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0x00',
          max: '0x1D',
          description: 'Output channel (to load)'
        }, {
          value: '0x1E',
          description: 'All output channels supported by the device'
        }, {
          value: '0x1F',
          description: 'Input channel (from mains supply)'
        }]
      }
    }, {
      data: 'Output value',
      shortcut: 'OV',
      description: {},
      info: {},
      bitoffs: '17',
      bitsize: '7',
      enum: {
        item: [{
          value: '0x00',
          description: 'Output value 0% or OFF'
        }, {
          min: '0x01',
          max: '0x64',
          description: 'Output value 1% to 100% or ON'
        }, {
          min: '0x65',
          max: '0x7E',
          description: 'Not used'
        }, {
          value: '0x7F',
          description: 'Output value not valid / not applicable'
        }]
      }
    }, {
      reserved: {},
      bitoffs: '16',
      bitsize: '1'
    }]
  }, {
    title: 'CMD 0x2 - Actuator Set Local',
    description: 'This message is sent to an actuator. It configures one or all channels of an actuator.\n                <br/>\n                <br/>Response Timing: None\n                <br/>\n                <br/>\n                RECOMMENDATION:\n                <br/>\n                In case the device implements an internal order for dim timers, this order\n                should be from “dim timer 1” (fast) to “dim timer 3” (slow).\n                The configured time shall always be interpreted for a full range (0 to 100%) dimming.\n                <br/>\n                <br/>\n                <img>graphics/EEP_D2-01-xx_CMD_02.png</img>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x02'
      }
    },
    datafield: [{
      data: 'Taught-in devices',
      shortcut: 'd/e',
      description: {},
      info: {},
      bitoffs: '0',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Disable taught-in devices (with different EEP)'
        }, {
          value: '0b1',
          description: 'Enable taught-in devices (with different EEP)'
        }]
      }
    }, {
      reserved: {},
      bitoffs: '1',
      bitsize: '3'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x02',
          description: 'ID 02'
        }
      }
    }, {
      data: 'Over current shut down',
      shortcut: 'OC',
      description: {},
      info: {},
      bitoffs: '8',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Over current shut down: static off'
        }, {
          value: '0b1',
          description: 'Over current shut down: automatic restart'
        }]
      }
    }, {
      data: 'reset over current shut down',
      shortcut: 'RO',
      description: {},
      info: {},
      bitoffs: '9',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Reset over current shut down: not active'
        }, {
          value: '0b1',
          description: 'Reset over current shut down: trigger signal'
        }]
      }
    }, {
      data: 'Local control',
      shortcut: 'LC',
      description: {},
      info: {},
      bitoffs: '10',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Disable local control'
        }, {
          value: '0b1',
          description: 'Enable local control'
        }]
      }
    }, {
      data: 'I/O channel',
      shortcut: 'I/O',
      description: {},
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0x00',
          max: '0x1D',
          description: 'Output channel (to load)'
        }, {
          value: '0x1E',
          description: 'All output channels supported by the device'
        }, {
          value: '0x1F',
          description: 'Input channel (from mains supply)'
        }]
      }
    }, {
      data: 'Dim timer 3',
      shortcut: 'DT3',
      description: {},
      info: {},
      bitoffs: '20',
      bitsize: '4',
      enum: {
        item: [{
          value: '0x00',
          description: 'Not used'
        }, {
          min: '0x01',
          max: '0x0F',
          description: 'Dim timer 3 [0,5 … 7,5s / steps 0,5s]'
        }]
      }
    }, {
      data: 'Dim timer 1',
      shortcut: 'DT1',
      description: {},
      info: {},
      bitoffs: '28',
      bitsize: '4',
      enum: {
        item: [{
          value: '0x00',
          description: 'Not used'
        }, {
          min: '0x01',
          max: '0x0F',
          description: 'Dim timer 1 [0,5 … 7,5s / steps 0,5s]'
        }]
      }
    }, {
      data: 'Dim timer 2',
      shortcut: 'DT2',
      description: {},
      info: {},
      bitoffs: '16',
      bitsize: '4',
      enum: {
        item: [{
          value: '0x00',
          description: 'Not used'
        }, {
          min: '0x01',
          max: '0x0F',
          description: 'Dim timer 2 [0,5 … 7,5s / steps 0,5s]'
        }]
      }
    }, {
      data: 'User interface indication',
      shortcut: 'd/n',
      description: {},
      info: {},
      bitoffs: '24',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'User interface indication: day operation'
        }, {
          value: '0b1',
          description: 'User interface indication: night operation'
        }]
      }
    }, {
      data: 'Power Failure',
      shortcut: 'PF',
      description: {},
      info: {},
      bitoffs: '25',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Disable Power Failure Detection'
        }, {
          value: '0b1',
          description: 'Enable Power Failure Detection'
        }]
      }
    }, {
      data: 'Default state',
      shortcut: 'DS',
      description: {},
      info: {},
      bitoffs: '26',
      bitsize: '2',
      enum: {
        item: [{
          value: '0b00',
          description: 'Default state: 0% or OFF'
        }, {
          value: '0b01',
          description: 'Default state: 100% or ON'
        }, {
          value: '0b10',
          description: 'Default state: remember previous state'
        }, {
          value: '0b11',
          description: 'Not used'
        }]
      }
    }]
  }, {
    title: 'CMD 0x3 - Actuator Status Query',
    description: 'This message is sent to an actuator. It requests the status of one or all channels of an actuator.\n                <br/>\n                <br/>\n                Response Timing:<br/>\n                An Actuator Status Response message shall be received within a maximum of 300ms from the time of transmission of this message.\n                In case no such response is received within this time frame the action shall be treated as completed without result.\n                <br/>\n                <img>graphics/EEP_D2-01-xx_CMD_03.png</img>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x03'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x03',
          description: 'ID 03'
        }
      }
    }, {
      data: 'I/O channel',
      shortcut: 'I/O',
      description: {},
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0x00',
          max: '0x1D',
          description: 'Output channel (to load)'
        }, {
          value: '0x1E',
          description: 'All output channels supported by the device'
        }, {
          value: '0x1F',
          description: 'Input channel (from mains supply)'
        }]
      }
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '3'
    }]
  }, {
    title: 'CMD 0x4 - Actuator Status Response',
    description: 'This message is sent by an actuator if one of the following events occurs:<br/>\n                          -\tStatus of one channel has been changed locally<br/>\n                          -\tMessage Actuator Status Query has been received<br/>\n                <br/>\n                Response Timing:<br/>\n                This message shall be sent within a maximum of 50ms from the time of reception of the Actuator Status Query message.<br/>\n                <br/>\n                <img>graphics/EEP_D2-01-xx_CMD_04.png</img>\n                <br/>\n                REMARK 1:<br/>\n                In case an Actuator Status Query message specifies a parameter that is not supported by the device being addresses, such device shall ignore the message and shall not answer using the Actuator Status Response message.<br/>\n                REMARK 2:<br/>\n                In case an Actuator Status Query message queries all output channels supported by a device being addresses, such device shall answer per each output channel by using an individual Actuator Measurement Response message.<br/>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x04'
      }
    },
    datafield: [{
      data: 'Power Failure',
      shortcut: 'PF',
      description: {},
      info: {},
      bitoffs: '0',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Power Failure Detection disabled/not supported'
        }, {
          value: '0b1',
          description: 'Power Failure Detection enabled'
        }]
      }
    }, {
      data: 'Power Failure Detection',
      shortcut: 'PFD',
      description: {},
      info: {},
      bitoffs: '1',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Power Failure not detected/not supported/disabled'
        }, {
          value: '0b1',
          description: 'Power Failure Detected'
        }]
      }
    }, {
      reserved: {},
      bitoffs: '2',
      bitsize: '2'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x04',
          description: 'ID 04'
        }
      }
    }, {
      data: 'Over current switch off',
      shortcut: 'OC',
      description: {},
      info: {},
      bitoffs: '8',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Over current switch off: ready / not supported'
        }, {
          value: '0b1',
          description: 'Over current switch off: executed'
        }]
      }
    }, {
      data: 'Error level',
      shortcut: 'EL',
      description: {},
      info: {},
      bitoffs: '9',
      bitsize: '2',
      enum: {
        item: [{
          value: '0b00',
          description: 'Error level 0: hardware OK'
        }, {
          value: '0b01',
          description: 'Error level 1: hardware warning'
        }, {
          value: '0b10',
          description: 'Error level 2: hardware failure'
        }, {
          value: '0b11',
          description: 'Error level not supported'
        }]
      }
    }, {
      data: 'I/O channel',
      shortcut: 'I/O',
      description: {},
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0x00',
          max: '0x1D',
          description: 'Output channel (to load)'
        }, {
          value: '0x1E',
          description: 'Not applicable, do not use'
        }, {
          value: '0x1F',
          description: 'Input channel (from mains supply)'
        }]
      }
    }, {
      data: 'Local control',
      shortcut: 'LC',
      description: {},
      info: {},
      bitoffs: '16',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Local control disabled / not supported'
        }, {
          value: '0b1',
          description: 'Local control enabled'
        }]
      }
    }, {
      data: 'Output value',
      shortcut: 'OV',
      description: {},
      info: {},
      bitoffs: '17',
      bitsize: '7',
      enum: {
        item: [{
          value: '0x00',
          description: 'Output value 0% or OFF'
        }, {
          min: '0x01',
          max: '0x64',
          description: 'Output value 1% to 100% or ON'
        }, {
          min: '0x65',
          max: '0x7E',
          description: 'Not used'
        }, {
          value: '0x7F',
          description: 'output value not valid / not set'
        }]
      }
    }]
  }, {
    title: 'CMD 0x5 - Actuator Set Measurement',
    description: 'The command defines values at offset 32 and at offset 40 which\n              are the limits for the transmission periodicity of messages.\n              MIT must not be set to 0, MAT >= MIT.\n                <br/>\n                <br/>Response Timing: None\n                <br/>\n                <br/>\n                <img>graphics/EEP_D2-01-xx_CMD_05.png</img>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x05'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      reserved: {},
      bitoffs: '20',
      bitsize: '1'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x05',
          description: 'ID 05'
        }
      }
    }, {
      data: 'Report measurement',
      shortcut: 'RM',
      description: {},
      info: {},
      bitoffs: '8',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Report measurement: query only'
        }, {
          value: '0b1',
          description: 'Report measurement: query / auto reporting'
        }]
      }
    }, {
      data: 'Reset measurement',
      shortcut: 'RE',
      description: {},
      info: {},
      bitoffs: '9',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Reset measurement: not active'
        }, {
          value: '0b1',
          description: 'Reset measurement: trigger signal'
        }]
      }
    }, {
      data: 'Measurement mode',
      shortcut: 'e/p',
      description: {},
      info: {},
      bitoffs: '10',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Energy measurement'
        }, {
          value: '0b1',
          description: 'Power measurement'
        }]
      }
    }, {
      data: 'I/O channel',
      shortcut: 'I/O',
      description: {},
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0x00',
          max: '0x1D',
          description: 'Output channel (to load)'
        }, {
          value: '0x1E',
          description: 'All output channels supported by the device'
        }, {
          value: '0x1F',
          description: 'Input channel (from mains supply)'
        }]
      }
    }, {
      data: 'Measurement delta to be reported',
      shortcut: 'MD',
      description: {},
      info: {},
      spread: [
        {
          bitoffs: 24,
          bitsize: 8
        }, {
          bitoffs: 16,
          bitsize: 4
        }
      ],
      range: {
        min: 0,
        max: 4095
      },
      scale: {
        min: 0,
        max: 4095
      },
      unit: {
        ref: 'UN'
      }
    }, {
      data: 'Unit',
      shortcut: 'UN',
      description: {},
      info: {},
      bitoffs: '21',
      bitsize: '3',
      enum: {
        item: [{
          value: '0x00',
          description: 'Energy [Ws]',
          unit: 'Ws'
        }, {
          value: '0x01',
          description: 'Energy [Wh]',
          unit: 'Wh'
        }, {
          value: '0x02',
          description: 'Energy [KWh]',
          unit: 'kWh'
        }, {
          value: '0x03',
          description: 'Power [W]',
          unit: 'W'
        }, {
          value: '0x04',
          description: 'Power [KW]',
          unit: 'KW'
        }, {
          min: '0x05',
          max: '0x07',
          description: 'Not used',
          unit: ''
        }]
      }
    }, {
      data: 'Maximum time between two subsequent actuator messages',
      shortcut: 'MAT',
      description: 'Measurement Response messages [10s]',
      info: {},
      bitoffs: '32',
      bitsize: '8',
      enum: {
        item: [{
          min: '1',
          max: '255',
          scale: {
            min: '10',
            max: '2550'
          },
          unit: 's'
        }, {
          value: '0',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Minimum time between two subsequent actuator messages',
      shortcut: 'MIT',
      description: 'Measurement Response messages [s]',
      info: {},
      bitoffs: '40',
      bitsize: '8',
      enum: {
        item: [{
          min: '1',
          max: '255',
          scale: {
            min: '1',
            max: '255'
          },
          unit: 's'
        }, {
          value: '0',
          description: 'Reserved'
        }]
      }
    }]
  }, {
    title: 'CMD 0x6 - Actuator Measurement Query',
    description: 'This message is sent to an actuator. The actuator replies with an Actuator Measurement Response message.\n                <br/>\n                <br/>Response Timing:\n                <br/>An Actuator Message Response message shall be received within a maximum of 300ms from the time of transmission of this message.\nIn case no such response is received within this time frame the action shall be treated as completed without result.\n                <br/>\n                <img>graphics/EEP_D2-01-xx_CMD_06.png</img>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x06'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x06',
          description: 'ID 06'
        }
      }
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '2'
    }, {
      data: 'Query',
      shortcut: 'qu',
      description: {},
      info: {},
      bitoffs: '10',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b0',
          description: 'Query energy'
        }, {
          value: '0b1',
          description: 'Query power'
        }]
      }
    }, {
      data: 'I/O channel',
      shortcut: 'I/O',
      description: {},
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0x00',
          max: '0x1D',
          description: 'Output channel (to load)'
        }, {
          value: '0x1E',
          description: 'All output channels supported by the device'
        }, {
          value: '0x1F',
          description: 'Input channel (from mains supply)'
        }]
      }
    }]
  }, {
    title: 'CMD 0x7 - Actuator Measurement Response',
    description: 'This message is sent by an actuator if one of the following events occurs:<br/>\n              -\tMeasurement results trigger an automated transmission (see Actuator Set Measurement message)<br/>\n              -\tMessage Actuator Measurement Query has been received\n                <br/>\n                <br/>Response Timing:<br/>\n                This message shall be sent within a maximum of 50ms from the time of reception of the Actuator Measurement Query message.\n                <br/>\n                <img>graphics/EEP_D2-01-xx_CMD_07.png</img>\n                <br/>\n                REMARK 1:<br/>\n                In case an Actuator Measurement Query message specifies a parameter that is not supported by the device addressed, such device shall ignore the message and shall not answer using the Actuator Measurement Response message.\n                <br/>\n                REMARK 2:<br/>\n                In case an Actuator Measurement Query message queries all output channels supported by a device being addresses, such device shall answer per each output channel by using an individual Actuator Measurement Response message.\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x07'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x07',
          description: 'ID 07'
        }
      }
    }, {
      data: 'Unit',
      shortcut: 'UN',
      description: {},
      info: {},
      bitoffs: '8',
      bitsize: '3',
      enum: {
        item: [{
          value: '0x00',
          description: 'Energy [Ws]'
        }, {
          value: '0x01',
          description: 'Energy [Wh]'
        }, {
          value: '0x02',
          description: 'Energy [KWh]'
        }, {
          value: '0x03',
          description: 'Power [W]'
        }, {
          value: '0x04',
          description: 'Power [KW]'
        }, {
          min: '0x05',
          max: '0x07',
          description: 'Not used'
        }]
      }
    }, {
      data: 'I/O channel',
      shortcut: 'I/O',
      description: {},
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0x00',
          max: '0x1D',
          description: 'Output channel (to load)'
        }, {
          value: '0x1E',
          description: 'Not applicable, do not use'
        }, {
          value: '0x1F',
          description: 'Input channel (from mains supply)'
        }]
      }
    }, {
      data: 'Measurement value (4 bytes)',
      shortcut: 'MV',
      description: '...',
      info: {},
      bitoffs: '16',
      bitsize: '32',
      range: {
        min: '0',
        max: '4294967295'
      },
      unit: 'N/A'
    }]
  }, {
    title: 'CMD 0x8 - Actuator Set Pilot Wire Mode',
    description: '<img>graphics/EEP_D2-01-xx_CMD_08.png</img>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x08'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '5'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x08',
          description: 'ID 08'
        }
      }
    }, {
      data: 'Pilotwire mode',
      shortcut: 'PM',
      description: {},
      info: {},
      bitoffs: '13',
      bitsize: '3',
      enum: {
        item: [{
          value: '0x00',
          description: 'Off'
        }, {
          value: '0x01',
          description: 'Comfort'
        }, {
          value: '0x02',
          description: 'Eco'
        }, {
          value: '0x03',
          description: 'Anti-freeze'
        }, {
          value: '0x04',
          description: 'Comfort-1'
        }, {
          value: '0x05',
          description: 'Comfort-2'
        }]
      }
    }]
  }, {
    title: 'CMD 0x9 - Actuator Pilot Wire Mode Query',
    description: '<img>graphics/EEP_D2-01-xx_CMD_09.png</img>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x09'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x09',
          description: 'ID 09'
        }
      }
    }]
  }, {
    title: 'CMD 0xA - Actuator Pilot Wire Mode Response',
    description: '<img>graphics/EEP_D2-01-xx_CMD_0A.png</img>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x0a'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '5'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x0A',
          description: 'ID 0A'
        }
      }
    }, {
      data: 'Pilotwire mode',
      shortcut: 'PM',
      description: {},
      info: {},
      bitoffs: '13',
      bitsize: '3',
      enum: {
        item: [{
          value: '0x00',
          description: 'Off'
        }, {
          value: '0x01',
          description: 'Comfort'
        }, {
          value: '0x02',
          description: 'Eco'
        }, {
          value: '0x03',
          description: 'Anti-freeze'
        }, {
          value: '0x04',
          description: 'Comfort-1'
        }, {
          value: '0x05',
          description: 'Comfort-2'
        }]
      }
    }]
  }, {
    title: 'CMD 0xB - Actuator Set External Interface Settings',
    description: '<img>graphics/EEP_D2-01-xx_CMD_0B.png</img>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x0b'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '3'
    }, {
      reserved: {},
      bitoffs: '51',
      bitsize: '5'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x0B',
          description: 'ID 0B'
        }
      }
    }, {
      data: 'I/O channel',
      shortcut: 'I/O',
      description: {},
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0x00',
          max: '0x1D',
          description: 'Output channel (to load)'
        }, {
          value: '0x1E',
          description: 'All output channels supported by the device'
        }, {
          value: '0x1F',
          description: 'Input channel (from mains supply)'
        }]
      }
    }, {
      data: 'Auto OFF Timer',
      shortcut: 'AOT',
      description: 'Timer to automatically set OFF output channel when it is set ON',
      info: {},
      bitoffs: '16',
      bitsize: '16',
      enum: {
        item: [{
          value: '0x0000',
          description: 'Timer deactivated'
        }, {
          min: '0x0001',
          max: '0xFFFE',
          scale: {
            min: '0.1',
            max: '6553.4'
          },
          unit: 's'
        }, {
          value: '0xFFFF',
          description: 'Does not modify saved value'
        }]
      }
    }, {
      data: 'Delay OFF Timer',
      shortcut: 'DOT',
      description: 'Delay timer before setting output channel to OFF value received by radio cmd',
      info: {},
      bitoffs: '32',
      bitsize: '16',
      enum: {
        item: [{
          value: '0x0000',
          description: 'Timer deactivated'
        }, {
          min: '0x0001',
          max: '0xFFFE',
          scale: {
            min: '0.1',
            max: '6553.4'
          },
          unit: 's'
        }, {
          value: '0xFFFF',
          description: 'Does not modify saved value'
        }]
      }
    }, {
      data: 'External Switch/Push Button',
      shortcut: 'EBM',
      description: 'External interface mode',
      info: {},
      bitoffs: '48',
      bitsize: '2',
      enum: {
        item: [{
          value: '0b00',
          description: 'Not applicable'
        }, {
          value: '0b01',
          description: 'External Switch'
        }, {
          value: '0b10',
          description: 'External Push Button'
        }, {
          value: '0b11',
          description: 'Auto detect'
        }]
      }
    }, {
      data: '2-state switch',
      shortcut: 'SWT',
      description: 'Switching state',
      info: {},
      bitoffs: '50',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b00',
          description: 'Change of key state sets ON or OFF'
        }, {
          value: '0b01',
          description: 'Specific ON/OFF positions.<br/>\n                    ON when contacts are closed.<br/>\n                    OFF when contacts are open.'
        }]
      }
    }]
  }, {
    title: 'CMD 0xC - Actuator External Interface Settings Query',
    description: '<img>graphics/EEP_D2-01-xx_CMD_0C.png</img>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x0c'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '3'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x0C',
          description: 'ID 0C'
        }
      }
    }, {
      data: 'I/O channel',
      shortcut: 'I/O',
      description: {},
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0x00',
          max: '0x1D',
          description: 'Output channel (to load)'
        }, {
          value: '0x1E',
          description: 'All output channels supported by the device'
        }, {
          value: '0x1F',
          description: 'Input channel (from mains supply)'
        }]
      }
    }]
  }, {
    title: 'CMD 0xD - Actuator External Interface Settings Response',
    description: '<img>graphics/EEP_D2-01-xx_CMD_0D.png</img>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x0d'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '3'
    }, {
      reserved: {},
      bitoffs: '51',
      bitsize: '5'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x0D',
          description: 'ID 0D'
        }
      }
    }, {
      data: 'I/O channel',
      shortcut: 'I/O',
      description: {},
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0x00',
          max: '0x1D',
          description: 'Output channel (to load)'
        }, {
          value: '0x1E',
          description: 'Not applicable'
        }, {
          value: '0x1F',
          description: 'Input channel (from mains supply)'
        }]
      }
    }, {
      data: 'Auto OFF Timer',
      shortcut: 'AOT',
      description: 'Timer to automatically set OFF output channel when it is set ON',
      info: {},
      bitoffs: '16',
      bitsize: '16',
      enum: {
        item: [{
          value: '0x0000',
          description: 'Timer deactivated'
        }, {
          min: '0x0001',
          max: '0xFFFE',
          scale: {
            min: '0.1',
            max: '6553.4'
          },
          unit: 's'
        }, {
          value: '0xFFFF',
          description: 'Does not modify saved value'
        }]
      }
    }, {
      data: 'Delay OFF Timer',
      shortcut: 'DOT',
      description: 'Delay timer before setting output channel to OFF value received by radio cmd',
      info: {},
      bitoffs: '32',
      bitsize: '16',
      enum: {
        item: [{
          value: '0x0000',
          description: 'Timer deactivated'
        }, {
          min: '0x0001',
          max: '0xFFFE',
          scale: {
            min: '0.1',
            max: '6553.4'
          },
          unit: 's'
        }, {
          value: '0xFFFF',
          description: 'Does not modify saved value'
        }]
      }
    }, {
      data: 'External Switch/Push Button',
      shortcut: 'EBM',
      description: 'External interface mode',
      info: {},
      bitoffs: '48',
      bitsize: '2',
      enum: {
        item: [{
          value: '0b00',
          description: 'Not applicable'
        }, {
          value: '0b01',
          description: 'External Switch'
        }, {
          value: '0b10',
          description: 'External Push Button'
        }, {
          value: '0b11',
          description: 'Auto detect'
        }]
      }
    }, {
      data: '2-state switch',
      shortcut: 'SWT',
      description: 'Switching state',
      info: {},
      bitoffs: '50',
      bitsize: '1',
      enum: {
        item: [{
          value: '0b00',
          description: 'Change of key state sets ON or OFF'
        }, {
          value: '0b01',
          description: 'Specific ON/OFF positions.\n                      <br/>ON when contacts are closed.\n                      <br/>OFF when contacts are open.'
        }]
      }
    }]
  }],
  originalIndex: 140,
  eep: 'd2-01-00',
  rorg_title: 'VLD Telegram',
  rorg_number: '0xD2',
  func_title: 'Electronic switches and dimmers with Energy Measurement and Local Control',
  func_number: '0x01',
  submitter: [
    'Team'
  ]
}
