export const d20500 = {
  number: '0x00',
  title: 'Type 0x00',
  status: 'released',
  description: '',
  case: [{
    title: 'CMD 1 - Go to Position and Angle',
    description: 'Once the actuator is configured either by the “Set Parameters” command\n              or through manual configuration (using local buttons) the position\n              of the blinds can be controlled with this command.\n              <br/>\n              When the actuator is set to “blockage” mode, neither local nor\n              central positioning and configuration commands will be executed.\n              This mode is intended for putting the device temporarily out of\n              service, e.g. for a maintenance operation.\n              <br/>\n              When the actuator is set to the “alarm” mode neither local nor\n              central positioning and configuration commands will be executed.\n              Before entering the “alarm” mode, the actuator will execute the\n              “alarm action” as configured by the “Set parameter” command.\n              <br/>\n              When this command is sent with the “deblockage” option, the actuator\n              terminates the “alarm” or “blockage” mode and enters the normal mode.\n              <br/>\n              <br/>\n              Exemplary illustration of data bytes 0 ... 3:\n              <br/>\n              <img>graphics/D2-05-xx_00.png</img>\n              <br/>',
    condition: {
      datafield: {
        bitoffs: '28',
        bitsize: '4',
        value: '0x01'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '1'
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '1'
    }, {
      reserved: {},
      bitoffs: '16',
      bitsize: '1'
    }, {
      reserved: {},
      bitoffs: '20',
      bitsize: '1'
    }, {
      data: 'Position',
      shortcut: 'POS',
      description: 'Vertical position',
      info: {},
      bitoffs: '1',
      bitsize: '7',
      enum: {
        item: [{
          min: '0',
          max: '100',
          scale: {
            min: '0',
            max: '100'
          },
          unit: '%'
        }, {
          value: '127',
          description: 'Do not change'
        }]
      }
    }, {
      data: 'Angle',
      shortcut: 'ANG',
      description: 'Rotation angle',
      info: {},
      bitoffs: '9',
      bitsize: '7',
      enum: {
        item: [{
          min: '0',
          max: '100',
          scale: {
            min: '0',
            max: '100'
          },
          unit: '%'
        }, {
          value: '127',
          description: 'Do not change'
        }]
      }
    }, {
      data: 'Repositioning',
      shortcut: 'REPO',
      description: 'How to adjust the internal positioning tracker\n                before going to the new position',
      info: {},
      bitoffs: '17',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'Go directly to POS/ANG',
          info: {}
        }, {
          value: '1',
          description: 'Go up (0%), then to POS/ANG'
        }, {
          value: '2',
          description: 'Go down (100%), then to POS/ANG'
        }, {
          value: '3 ... 7',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Locking modes',
      shortcut: 'LOCK',
      description: 'Set/reset locking modes',
      info: {},
      bitoffs: '21',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'Do not change',
          info: {}
        }, {
          value: '1',
          description: 'Set blockage mode'
        }, {
          value: '2',
          description: 'Set alarm mode'
        }, {
          value: '3 ... 6',
          description: 'Reserved'
        }, {
          value: '7',
          description: 'Deblockage'
        }]
      }
    }, {
      data: 'Channel',
      shortcut: 'CHN',
      description: 'Channel address',
      info: {},
      bitoffs: '24',
      bitsize: '4',
      enum: {
        item: {
          value: '0',
          description: 'Channel 1'
        }
      }
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '28',
      bitsize: '4',
      enum: {
        item: {
          value: '1',
          description: 'Goto command'
        }
      }
    }]
  }, {
    title: 'CMD 2 - Stop',
    description: 'This command immediately stops a running blind motor. It has no\n              effect when the actuator is in “blockage” or “alarm” mode,\n              i.e. it will not stop an eventual “go up” or “go down” alarm action.\n              <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x02'
      }
    },
    datafield: [{
      data: 'Channel',
      shortcut: 'CHN',
      description: 'Channel address',
      info: {},
      bitoffs: '0',
      bitsize: '4',
      enum: {
        item: {
          value: '0',
          description: 'Channel 1'
        }
      }
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '2',
          description: 'Stop command'
        }
      }
    }]
  }, {
    title: 'CMD 3 - Query Position and Angle',
    description: 'This command requests the actuator to return a “reply” command.\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x03'
      }
    },
    datafield: [{
      data: 'Channel',
      shortcut: 'CHN',
      description: 'Channel address',
      info: {},
      bitoffs: '0',
      bitsize: '4',
      enum: {
        item: {
          value: '0',
          description: 'Channel 1'
        }
      }
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '3',
          description: 'Query command'
        }
      }
    }]
  }, {
    title: 'CMD 4 - Reply Position and Angle',
    description: 'Either upon request (“Query” command) or after an internal trigger\n              (see EEP Properties) the actuator sends this command to inform\n              about its current state.\n              <br/>',
    condition: {
      datafield: {
        bitoffs: '28',
        bitsize: '4',
        value: '0x04'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '1'
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '1'
    }, {
      reserved: {},
      bitoffs: '16',
      bitsize: '5'
    }, {
      data: 'Position',
      shortcut: 'POS',
      description: 'Current vertical position',
      info: {},
      bitoffs: '1',
      bitsize: '7',
      enum: {
        item: [{
          min: '0',
          max: '100',
          scale: {
            min: '0',
            max: '100'
          },
          unit: '%'
        }, {
          value: '127',
          description: 'Position unknown, will be known<br/> after the next goto cmd'
        }]
      }
    }, {
      data: 'Angle',
      shortcut: 'ANG',
      description: 'Current rotation angle',
      info: {},
      bitoffs: '9',
      bitsize: '7',
      enum: {
        item: [{
          min: '0',
          max: '100',
          scale: {
            min: '0',
            max: '100'
          },
          unit: '%'
        }, {
          value: '127',
          description: 'Angle unknown, will be known<br/> after the\n                    next goto cmd'
        }]
      }
    }, {
      data: 'Locking modes',
      shortcut: 'LOCK',
      description: 'Current locking mode',
      info: {},
      bitoffs: '21',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'Normal (no lock)',
          info: {}
        }, {
          value: '1',
          description: 'Blockage mode'
        }, {
          value: '2',
          description: 'Alarm mode'
        }, {
          value: '3 ... 7',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Channel',
      shortcut: 'CHN',
      description: 'Channel address',
      info: {},
      bitoffs: '24',
      bitsize: '4',
      enum: {
        item: {
          value: '0',
          description: 'Channel 1'
        }
      }
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '28',
      bitsize: '4',
      enum: {
        item: {
          value: '4',
          description: 'Reply command'
        }
      }
    }]
  }, {
    title: 'CMD 5 - Set parameters',
    description: 'This command sets one or multiple configuration parameters of the\n              actuator. When a parameter value is set to “-> no change“ this\n              parameter will not be modified. The VERT and ROT parameters describe\n              the duration needed by the motor for a full run of the blind, or\n              for a complete turn of the slats, respectively.\n              They have to be measured on site and assigned to the actuator.\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '36',
        bitsize: '4',
        value: '0x05'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '1'
    }, {
      reserved: {},
      bitoffs: '24',
      bitsize: '5'
    }, {
      data: 'Set vertical',
      shortcut: 'VERT',
      description: 'Measured duration of a vertical run',
      info: {},
      bitoffs: '1',
      bitsize: '15',
      enum: {
        item: [{
          min: '500',
          max: '30000',
          scale: {
            min: '5000',
            max: '300000'
          },
          unit: 'ms'
        }, {
          value: '0 ... 499',
          description: 'Reserved'
        }, {
          value: '32767 (0x7FFF)',
          description: '-> No change'
        }]
      }
    }, {
      data: 'Set rotation',
      shortcut: 'ROT',
      description: 'Measured duration of rotation',
      info: {},
      bitoffs: '16',
      bitsize: '8',
      enum: {
        item: [{
          min: '1',
          max: '254',
          scale: {
            min: '10',
            max: '2540'
          },
          unit: 'ms'
        }, {
          value: '0',
          description: 'No rotation'
        }, {
          value: '255',
          description: '-> No change'
        }]
      }
    }, {
      data: 'Set alarm action',
      shortcut: 'AA',
      description: 'Besides locking all other commands entering the\n                alarm mode results in',
      info: {},
      bitoffs: '29',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'No action',
          info: {}
        }, {
          value: '1',
          description: 'Immediate stop'
        }, {
          value: '2',
          description: 'Go up (0%)'
        }, {
          value: '3',
          description: 'Go down (100%)'
        }, {
          value: '4 ... 6',
          description: 'Reserved'
        }, {
          value: '7',
          description: '-> No change'
        }]
      }
    }, {
      data: 'Channel',
      shortcut: 'CHN',
      description: 'Channel address',
      info: {},
      bitoffs: '32',
      bitsize: '4',
      enum: {
        item: {
          value: '0',
          description: 'Channel 1'
        }
      }
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '36',
      bitsize: '4',
      enum: {
        item: {
          value: '5',
          description: 'Set parameters command'
        }
      }
    }]
  }],
  originalIndex: 181,
  eep: 'd2-05-00',
  rorg_title: 'VLD Telegram',
  rorg_number: '0xD2',
  func_title: 'Blinds Control for Position and Angle',
  func_number: '0x05',
  submitter: [
    'AWAG Elektrotechnik AG'
  ]
}
