export const d21101 = {
  number: '0x01',
  title: 'Type 0x01',
  status: 'released',
  case: [{
    title: 'Message type A / ID 0 (First switch press after sleep-mode, request new data)',
    description: 'Direction: Sensor -> Gateway\n              <br/><br/>\n              <b>Bit 0.7</b> indicates which setpoint type is actual used at the device.\n              The difference is made at the visualization of the setpoint (real\n              temperature setpoint (24.5°C) or setpoint shift (+ 3.0°C)) and this\n              information is needed for interpreting the value of DB2 at Message\n              Type C (ID2).\n              <br/>\n              <img>graphics/D2-11-00_ID0.png</img>\n              <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x00'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '1',
      bitsize: '3'
    }, {
      data: 'Setpoint type',
      shortcut: 'SPT',
      description: 'Setpoint type actual used by the device<br/>\n                (temperature correction / temperature setpoint)',
      info: {},
      bitoffs: '0',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Temperature correction'
        }, {
          value: '1',
          description: 'Temperature setpoint'
        }]
      }
    }, {
      data: 'Message ID',
      shortcut: 'MID',
      description: 'Message Type A, ID-0',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: [{
        item: {
          value: '0',
          description: 'ID-0'
        }
      }, {
        item: {
          value: '1',
          description: 'ID-1'
        }
      }, {
        item: {
          value: '2',
          description: 'ID-2'
        }
      }, {
        item: {
          min: '3',
          max: '15',
          description: 'Reserved'
        }
      }]
    }]
  }, {
    title: 'Message type B / ID 1 (Override device parameter, reply to data request)',
    description: 'Direction: Gateway -> Sensor\n                <br/>\n                <br/>\n                <b>Bit 3.7</b> may be used for setting new setpoint type at the\n                device. If no change is needed mirroring Bit 0.7 of the last\n                received Message Type A is required.\n                <br/>\n                <br/>\n                <b>Byte 2</b> may be used for overwriting the actual setpoint\n                shift at the device (i.e. for resetting the setpoint shift at the\n                evening to default value). If no change is needed mirroring Byte 2\n                of the last received Message-Type C is required.\n                <br/>\n                <br/>\n                <b>Byte 1</b> may be used for setting new basesetpoint at the\n                device. If no change is needed mirroring Byte 1 of the last\n                received Message-Type C is required.\n                <br/>\n                <br/>\n                <b>Bit 0.7 … 0.4</b> may be used for setting new valid setpoint\n                shift at the device. If no change is needed mirroring Bit0.7 … 0.4\n                of the last received Message-Type C is required.\n                <br/>\n                <img>graphics/D2-11-00_ID1.png</img>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x01'
      }
    },
    datafield: [{
      data: 'Set Setpoint type',
      shortcut: 'SPT',
      description: 'Set setpoint type to be used by the device',
      info: {},
      bitoffs: '0',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Temperature correction'
        }, {
          value: '1',
          description: 'Temperature setpoint'
        }]
      }
    }, {
      data: 'Display heating symbol',
      shortcut: 'DHS',
      description: 'Set/Clear heating symbol at the display',
      info: {},
      bitoffs: '1',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Heating symbol off'
        }, {
          value: '1',
          description: 'Heating symbol on'
        }]
      }
    }, {
      data: 'Display cooling symbol',
      shortcut: 'DCS',
      description: 'Set/Clear cooling symbol at the display',
      info: {},
      bitoffs: '2',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Cooling symbol off'
        }, {
          value: '1',
          description: 'Cooling symbol on'
        }]
      }
    }, {
      data: 'Display “window open” symbol',
      shortcut: 'SSW',
      description: 'Set/Clear “window open” symbol at the display',
      info: {},
      bitoffs: '3',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: '“Window open” symbol off'
        }, {
          value: '1',
          description: '“Window open” symbol on'
        }]
      }
    }, {
      data: 'Message ID',
      shortcut: 'MID',
      description: 'Message Type B, ID-1',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: [{
        item: {
          value: '0',
          description: 'ID-0'
        }
      }, {
        item: {
          value: '1',
          description: 'ID-1'
        }
      }, {
        item: {
          value: '2',
          description: 'ID-2'
        }
      }, {
        item: {
          min: '3',
          max: '15',
          description: 'Reserved'
        }
      }]
    }, {
      data: 'Temperature correction',
      shortcut: 'OSO',
      description: 'Override Setpoint offset (linear, min. - … max. +)\n                <br/>(valid temperature correction)',
      info: {},
      bitoffs: '8',
      bitsize: '8',
      enum: {
        item: {
          min: '0',
          max: '255',
          scale: {
            min: '0',
            max: '255'
          },
          unit: 'K'
        }
      }
    }, {
      data: 'Basesetpoint',
      shortcut: 'BSP',
      description: 'Set basesetpoint for visualization of the\n                temperature setpoint',
      info: {},
      bitoffs: '16',
      bitsize: '8',
      enum: {
        item: [{
          min: '0',
          max: '14',
          description: 'Reserved'
        }, {
          min: '15',
          max: '30',
          scale: {
            min: '15',
            max: '30'
          },
          unit: '°C'
        }, {
          min: '31',
          max: '255',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Valid temperature correction',
      shortcut: 'COA',
      description: 'Set valid temperature correction',
      info: {},
      bitoffs: '24',
      bitsize: '4',
      enum: {
        item: [{
          value: '0',
          description: 'Reserved'
        }, {
          value: '1',
          description: '-1 … +1 K'
        }, {
          value: '2',
          description: '-2 … +2 K'
        }, {
          value: '3',
          description: '-3 … +3 K'
        }, {
          value: '4',
          description: '-4 … +4 K'
        }, {
          value: '5',
          description: '-5 … +5 K'
        }, {
          value: '6',
          description: '-6 … +6 K'
        }, {
          value: '7',
          description: '-7 … +7 K'
        }, {
          value: '8',
          description: '-8 … +8 K'
        }, {
          value: '9',
          description: '-9 … +9 K'
        }, {
          value: '10',
          description: '-10 … +10 K'
        }, {
          min: '11',
          max: '15',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Fan Speed',
      shortcut: 'OFS',
      description: 'Override actual Fan Speed',
      info: {},
      bitoffs: '28',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'Auto'
        }, {
          value: '1',
          description: 'Speed 0'
        }, {
          value: '2',
          description: 'Speed 1'
        }, {
          value: '3',
          description: 'Speed 2'
        }, {
          value: '4',
          description: 'Speed 3'
        }, {
          min: '5',
          max: '6',
          description: 'Reserved'
        }, {
          value: '7',
          description: 'Not available'
        }]
      }
    }, {
      data: 'Occupancy State',
      shortcut: 'OOS',
      description: 'Override actual Occupancy State',
      info: {},
      bitoffs: '31',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'State Unoccupied'
        }, {
          value: '1',
          description: 'State Occupied'
        }]
      }
    }]
  }, {
    title: 'Message type C / ID 2 (Transmit actual data)',
    description: 'Direction: Sensor -> Gateway\n                <br/>\n                <br/>\n                <b>Bit 5.7</b> indicates which setpoint type is actual used at the\n                device. The difference is made at the visualization of the setpoint\n                (real temperature setpoint (24.5 °C) or setpoint shift (+ 3.0 °C))\n                and this information is needed for interpreting the value of DB2.\n                <br/>\n                <br/>\n                <b>Byte 4</b> transmits the actual measured temperature.\n                <br/>\n                <br/>\n                <b>Byte 2</b> transmits the actual setpoint shift. How to interpret\n                this value is a combination of Bit 5.7, Byte 1 and Bit 0.7 … 0.4.\n                <br/>\n                If the actual setpoint type is setpoint shift, then the value of\n                Byte 2 only represents the scaled valid setpoint shift at Bit 0.7 … 0.4.\n                <br/>\n                If the setpoint type is temperature setpoint, then the temperature\n                setpoint is calculated as sum of the internal basesetpoint at\n                Byte 1 and the scaled valid setpoint shift at Bit 0.7 … 0.4,\n                transmitted at Byte 2.\n                <br/>\n                <br/>\n                <b>Byte 1</b> transmits the actual, at the device stored, basesetpoint.\n                <br/>\n                <br/>\n                <b>Bit 0.7 … 0.4</b> transmits the actual valid, at the device stored,\n                setpoint shift.\n                <br/>\n                <br/>\n                <img>graphics/D2-11-00_ID2.png</img>\n                <br/>',
    condition: {
      datafield: {
        bitoffs: '4',
        bitsize: '4',
        value: '0x02'
      }
    },
    datafield: [{
      reserved: {},
      bitoffs: '3',
      bitsize: '1'
    }, {
      data: 'Setpoint type',
      shortcut: 'SPT',
      description: 'Setpoint type actual used by the device\n                <br/>\n                (temperature correction / temperature setpoint)',
      info: {},
      bitoffs: '0',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Temperature correction'
        }, {
          value: '1',
          description: 'Temperature setpoint'
        }]
      }
    }, {
      data: 'Telegram Type',
      shortcut: 'TT',
      description: 'Telegram Trigger',
      info: {},
      bitoffs: '1',
      bitsize: '2',
      enum: {
        item: [{
          value: '0',
          description: 'Heartbeat'
        }, {
          value: '1',
          description: 'Change of temperature- or humidity value'
        }, {
          value: '2',
          description: 'User caused parameter change'
        }]
      }
    }, {
      data: 'Message ID',
      shortcut: 'MID',
      description: 'Message Type C, ID-2',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: [{
        item: {
          value: '0',
          description: 'ID-0'
        }
      }, {
        item: {
          value: '1',
          description: 'ID-1'
        }
      }, {
        item: {
          value: '2',
          description: 'ID-2'
        }
      }, {
        item: {
          min: '3',
          max: '15',
          description: 'Reserved'
        }
      }]
    }, {
      data: 'Temperature',
      shortcut: 'TEMP',
      description: 'Temperature',
      info: {},
      bitoffs: '8',
      bitsize: '8',
      range: {
        min: '0',
        max: '255'
      },
      scale: {
        min: '0',
        max: '+40'
      },
      unit: '°C'
    }, {
      data: 'Humidity',
      shortcut: 'HUMI',
      description: 'Humidity',
      info: {},
      bitoffs: '16',
      bitsize: '8',
      range: {
        min: '0',
        max: '250'
      },
      scale: {
        min: '0',
        max: '+100'
      },
      unit: '%rH'
    }, {
      data: 'Setpoint offset',
      shortcut: 'SP',
      description: 'Setpoint shift, linear<br/>\n                (refers to valid setpoint shift at DB0.7 … DB0.4)',
      info: {},
      bitoffs: '24',
      bitsize: '8',
      range: {
        min: '0',
        max: '255'
      },
      scale: {
        ref: 'BSB'
      },
      unit: 'K'
    }, {
      data: 'Basesetpoint',
      shortcut: 'IBS',
      description: 'Internal basesetpoint, required for setpoint\n                type “temperature setpoint”',
      info: {},
      bitoffs: '32',
      bitsize: '8',
      enum: {
        item: [{
          min: '0',
          max: '14',
          description: 'Reserved'
        }, {
          min: '15',
          max: '30',
          scale: {
            min: '15',
            max: '30'
          },
          unit: '°C'
        }, {
          min: '31',
          max: '255',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Valid temperature correction',
      shortcut: 'BSB',
      description: 'Valid temperature correction',
      info: {},
      bitoffs: '40',
      bitsize: '4',
      enum: {
        item: [{
          value: '0',
          description: 'Reserved'
        }, {
          value: '1',
          scale: {
            min: '-1',
            max: '1'
          },
          unit: 'K'
        }, {
          value: '2',
          scale: {
            min: '-2',
            max: '2'
          },
          unit: 'K'
        }, {
          value: '3',
          scale: {
            min: '-3',
            max: '3'
          },
          unit: 'K'
        }, {
          value: '4',
          scale: {
            min: '-4',
            max: '4'
          },
          unit: 'K'
        }, {
          value: '5',
          scale: {
            min: '-5',
            max: '5'
          },
          unit: 'K'
        }, {
          value: '6',
          scale: {
            min: '-6',
            max: '6'
          },
          unit: 'K'
        }, {
          value: '7',
          scale: {
            min: '-7',
            max: '7'
          },
          unit: 'K'
        }, {
          value: '8',
          scale: {
            min: '-8',
            max: '8'
          },
          unit: 'K'
        }, {
          value: '9',
          scale: {
            min: '-9',
            max: '9'
          },
          unit: 'K'
        }, {
          value: '10',
          scale: {
            min: '-10',
            max: '10'
          },
          unit: 'K'
        }, {
          min: '11',
          max: '15',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Fan Speed',
      shortcut: 'FS',
      description: 'Fan Speed',
      info: {},
      bitoffs: '44',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'Auto'
        }, {
          value: '1',
          description: 'Speed 0'
        }, {
          value: '2',
          description: 'Speed 1'
        }, {
          value: '3',
          description: 'Speed 2'
        }, {
          value: '4',
          description: 'Speed 3'
        }, {
          min: '5',
          max: '6',
          description: 'Reserved'
        }, {
          value: '7',
          description: 'Not available'
        }]
      }
    }, {
      data: 'Occupancy State',
      shortcut: 'OS',
      description: 'Occupancy State',
      info: {},
      bitoffs: '47',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'State Unoccupied'
        }, {
          value: '1',
          description: 'State Occupied'
        }]
      }
    }]
  }],
  originalIndex: 186,
  eep: 'd2-11-01',
  rorg_title: 'VLD Telegram',
  rorg_number: '0xD2',
  func_title: 'Bidirectional Room Operating Panel',
  func_number: '0x11',
  description: '',
  submitter: []
}
