export const d23000 = {
  number: '0x00',
  title: 'Type 0x00',
  status: 'released',
  description: '',
  case: [{
    title: 'CMD 0x1 - Set heating controls output',
    description: 'This message is sent to a floor heating actuator. It controls the valve position\n              of one channel or of all channels of the floor heating controls.\n                <br/>\n                <br/>Sender: controller; send type: broadcast or addressed; expected response: CMD 0x3\n                <br/>',
    datafield: [{
      data: 'Valve control period / PWM signal interval',
      shortcut: 'PERIOD',
      description: 'Total on-off time for two-position valve controller\n                  <br/>(T valve open + T valve closed)',
      info: {},
      bitoffs: '0',
      bitsize: '4',
      enum: {
        item: [{
          value: '0',
          description: 'Local default / no change',
          info: {}
        }, {
          value: '1',
          description: '1 s'
        }, {
          value: '2',
          description: '2 s'
        }, {
          value: '3',
          description: '5 s'
        }, {
          value: '4',
          description: '10 s'
        }, {
          value: '5',
          description: '20 s'
        }, {
          value: '6',
          description: '50 s'
        }, {
          value: '7',
          description: '100 s'
        }, {
          value: '8',
          description: '200 s'
        }, {
          value: '9',
          description: '500 s'
        }, {
          value: '10',
          description: '1000 s'
        }, {
          min: '11',
          max: '15',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x01',
          description: 'ID 01'
        }
      }
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '2'
    }, {
      data: 'Valve type',
      shortcut: 'VTYP',
      description: 'Type of connected valve',
      info: {},
      bitoffs: '10',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'Valve normally closed (N.C.)',
          info: {}
        }, {
          value: '1',
          description: 'Valve normally open (N.O.)'
        }]
      }
    }, {
      data: 'Heating channel',
      shortcut: 'HCH',
      description: 'The heating channel that should be set',
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0',
          max: '15',
          description: 'A valid channel number',
          info: {}
        }, {
          min: '16',
          max: '30',
          description: 'Reserved'
        }, {
          value: '31',
          description: 'All valid channels'
        }]
      }
    }, {
      data: 'Run init sequence',
      shortcut: 'RIN',
      description: 'Measure and store the valve zero point',
      info: {},
      bitoffs: '16',
      bitsize: '1',
      enum: {
        item: [{
          value: '0',
          description: 'No action',
          info: {}
        }, {
          value: '1',
          description: 'Run init sequence'
        }]
      }
    }, {
      data: 'Valve position set point',
      shortcut: 'POS',
      description: 'Valve set point 0…100% (0=closed, 100=open)',
      info: {},
      bitoffs: '17',
      bitsize: '7',
      range: {
        min: '0',
        max: '100'
      },
      scale: {
        min: '0',
        max: '100'
      },
      unit: '%'
    }]
  }, {
    title: 'CMD 0x2 - Heating controls status query',
    description: 'This message is sent to a floor heating actuator.\n              It requests the status of one channel or the status of the global\n              control unit of an actuator.\n                <br/>\n                <br/>Sender: controller; send type: broadcast or addressed; expected response: CMD 0x3\n                <br/>',
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x02',
          description: 'ID 02'
        }
      }
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '3'
    }, {
      data: 'Heating channel',
      shortcut: 'HCH',
      description: 'The heating channel that should be reported',
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0',
          max: '15',
          description: 'A valid channel number',
          info: {}
        }, {
          min: '16',
          max: '28',
          description: 'Reserved'
        }, {
          value: '29',
          description: 'All valid channels'
        }, {
          value: '30',
          description: 'All valid channels and global device status'
        }, {
          value: '31',
          description: 'Global device status only'
        }]
      }
    }]
  }, {
    title: 'CMD 0x3 - Heating controls status response / CH = 0...15',
    description: 'This message is sent by a floor heating controls if one of the following\n              events occurs:\n                <br/>- Message "status query" has been received (CMD 0x2).\n                <br/>- Status of one channel or temperature has changed.\n                <br/>\n                <br/>Sender: actuator; send type: broadcast; maximum send delay 1 s.\n                <br/>\n                <br/>If the response is for single channel data (CH = 0…15):\n                <br/>',
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x03',
          description: 'ID 03'
        }
      }
    }, {
      data: 'Status / Error',
      shortcut: 'STATUS',
      description: 'Status / Error indication of given channel',
      info: {},
      bitoffs: '8',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'No fault',
          info: {}
        }, {
          value: '1',
          description: 'General error'
        }, {
          value: '2',
          description: 'Init sequence running'
        }, {
          value: '3',
          description: 'Channel not available'
        }, {
          value: '4',
          description: 'Temperature sensor error'
        }, {
          value: '5',
          description: 'Valve error'
        }, {
          value: '6',
          description: 'Temperature sensor and valve error'
        }, {
          value: '7',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Heating channel',
      shortcut: 'HCH',
      description: 'The heating channel that is reported',
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0',
          max: '15',
          description: 'A valid channel number',
          info: {}
        }, {
          min: '16',
          max: '31',
          description: 'Reserved'
        }]
      }
    }, {
      reserved: {},
      bitoffs: '16',
      bitsize: '1'
    }, {
      data: 'Valve position',
      shortcut: 'POS',
      description: 'Actual valve position 0…100% (0=closed, 100=open)',
      info: {},
      bitoffs: '17',
      bitsize: '7',
      range: {
        min: '0',
        max: '100'
      },
      scale: {
        min: '0',
        max: '100'
      },
      unit: '%'
    }, {
      data: 'Return temperature',
      shortcut: 'TEMPRET',
      description: 'The current return temperature of the channel',
      info: {},
      bitoffs: '24',
      bitsize: '8',
      range: {
        min: '0',
        max: '180'
      },
      scale: {
        min: '0',
        max: '90'
      },
      unit: '°C'
    }]
  }, {
    title: 'CMD 0x3 - Heating controls status response / CH = 31',
    description: 'If the response is for global floor heating controls unit data (CH = 31):\n                <br/>',
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x03',
          description: 'ID 03'
        }
      }
    }, {
      data: 'Status / Error',
      shortcut: 'STATUS',
      description: 'Global unit status',
      info: {},
      bitoffs: '8',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'No fault',
          info: {}
        }, {
          value: '1',
          description: 'General error'
        }, {
          value: '2',
          description: 'Supply temperature error'
        }, {
          value: '3',
          description: 'Return temperature error'
        }, {
          value: '4',
          description: 'Error on both sensors'
        }, {
          min: '5',
          max: '7',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Heating channel',
      shortcut: 'HCH',
      description: 'The heating channel that is reported (=global unit)',
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: {
          value: '31',
          description: 'Unit status only',
          info: {}
        }
      }
    }, {
      data: 'Supply temperature',
      shortcut: 'TSUP',
      description: 'The current supply temperature of the unit',
      info: {},
      bitoffs: '16',
      bitsize: '8',
      range: {
        min: '0',
        max: '180'
      },
      scale: {
        min: '0',
        max: '90'
      },
      unit: '°C'
    }, {
      data: 'Return temperature',
      shortcut: 'TRET',
      description: 'The current common return temperature',
      info: {},
      bitoffs: '24',
      bitsize: '8',
      range: {
        min: '0',
        max: '180'
      },
      scale: {
        min: '0',
        max: '90'
      },
      unit: '°C'
    }]
  }, {
    title: 'CMD 0x6 - Set meter configuration / MBUS (BUS = 1)',
    description: 'This message is sent to a metering device gateway to configure the meter\n              settings for one channel.\n                <br/>\n                <br/>Sender: controller; send type: broadcast or addressed.\n                <br/>',
    datafield: [{
      data: 'Report measurement',
      shortcut: 'RM',
      description: 'Minimum auto reporting interval',
      info: {},
      bitoffs: '0',
      bitsize: '4',
      enum: {
        item: [{
          value: '0',
          description: 'No auto reporting',
          info: {}
        }, {
          value: '1',
          description: 'Min. 1 s interval'
        }, {
          value: '2',
          description: 'Min. 3 s interval'
        }, {
          value: '3',
          description: 'Min. 10 s interval'
        }, {
          value: '4',
          description: 'Min. 30 s interval'
        }, {
          value: '5',
          description: 'Min. 100 s interval'
        }, {
          value: '6',
          description: 'Min. 300 s interval'
        }, {
          value: '7',
          description: 'Min. 1000 s interval'
        }, {
          min: '8',
          max: '15',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x06',
          description: 'ID 06'
        }
      }
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '1'
    }, {
      data: 'Meter bus type',
      shortcut: 'BUS',
      description: 'The meter bus that should be configured',
      info: {},
      bitoffs: '9',
      bitsize: '2',
      enum: {
        item: [{
          value: '0',
          description: 'Reserved',
          info: {}
        }, {
          value: '1',
          description: 'MBUS'
        }, {
          value: '2',
          description: 'S0'
        }, {
          value: '3',
          description: 'D0'
        }]
      }
    }, {
      data: 'Meter channel index',
      shortcut: 'MCH',
      description: 'The meter bus that should be configured',
      info: {},
      bitoffs: '11',
      bitsize: '5',
      range: {
        min: '0',
        max: '30'
      },
      scale: {
        min: '0',
        max: '30'
      },
      unit: '1'
    }, {
      reserved: {},
      bitoffs: '16',
      bitsize: '2'
    }, {
      data: 'Meter 1 units',
      shortcut: 'UNIT1',
      description: 'Physical units of first measured quantity\n                  <br/>(imported value)',
      info: {},
      bitoffs: '18',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'No reading (unconfigured)',
          info: {}
        }, {
          value: '1',
          description: 'Current value W, accumulated value kWh'
        }, {
          value: '2',
          description: 'Current value W, accumulated value Wh'
        }, {
          value: '3',
          description: 'Accumulated value kWh only'
        }, {
          value: '4',
          description: 'Current value m3/h, accumulated value m3'
        }, {
          value: '5',
          description: 'Current value dm3/h, accumulated value dm3'
        }, {
          value: '6',
          description: 'Accumulated value m3 only'
        }, {
          value: '7',
          description: 'Digital counter'
        }]
      }
    }, {
      data: 'Meter 2 units',
      shortcut: 'UNIT2',
      description: 'Physical units of second measured quantity\n                  <br/>(exported value)',
      info: {},
      bitoffs: '21',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'No reading (unconfigured)',
          info: {}
        }, {
          value: '1',
          description: 'Current value W, accumulated value kWh'
        }, {
          value: '2',
          description: 'Current value W, accumulated value Wh'
        }, {
          value: '3',
          description: 'Accumulated value kWh only'
        }, {
          value: '4',
          description: 'Current value m3/h, accumulated value m3'
        }, {
          value: '5',
          description: 'Current value dm3/h, accumulated value dm3'
        }, {
          value: '6',
          description: 'Accumulated value m3 only'
        }, {
          value: '7',
          description: 'Digital counter'
        }]
      }
    }, {
      data: 'Primary Address',
      shortcut: 'ADDR',
      description: 'The primary MBUS address of the meter',
      info: {},
      bitoffs: '24',
      bitsize: '8',
      range: {
        min: '1',
        max: '250'
      },
      scale: {
        min: '1',
        max: '250'
      },
      unit: '1'
    }, {
      reserved: {},
      data: {},
      shortcut: {},
      description: {},
      bitoffs: '32',
      bitsize: '40',
      enum: {
        item: {
          value: '0',
          description: 'NDF',
          info: {}
        }
      }
    }]
  }, {
    title: 'CMD 0x6 - Set meter configuration / S0 (BUS = 2)',
    description: {},
    datafield: [{
      data: 'Report measurement',
      shortcut: 'RM',
      description: 'Minimum auto reporting interval',
      info: {},
      bitoffs: '0',
      bitsize: '4',
      enum: {
        item: [{
          value: '0',
          description: 'No auto reporting',
          info: {}
        }, {
          value: '1',
          description: 'Min. 1 s interval'
        }, {
          value: '2',
          description: 'Min. 3 s interval'
        }, {
          value: '3',
          description: 'Min. 10 s interval'
        }, {
          value: '4',
          description: 'Min. 30 s interval'
        }, {
          value: '5',
          description: 'Min. 100 s interval'
        }, {
          value: '6',
          description: 'Min. 300 s interval'
        }, {
          value: '7',
          description: 'Min. 1000 s interval'
        }, {
          min: '8',
          max: '15',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x06',
          description: 'ID 06'
        }
      }
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '1'
    }, {
      data: 'Meter bus type',
      shortcut: 'BUS',
      description: 'The meter bus that should be configured',
      info: {},
      bitoffs: '9',
      bitsize: '2',
      enum: {
        item: [{
          value: '0',
          description: 'Reserved',
          info: {}
        }, {
          value: '1',
          description: 'MBUS'
        }, {
          value: '2',
          description: 'S0'
        }, {
          value: '3',
          description: 'D0'
        }]
      }
    }, {
      data: 'Meter channel index',
      shortcut: 'MCH',
      description: 'The meter number of given bus that should be configured',
      info: {},
      bitoffs: '11',
      bitsize: '5',
      range: {
        min: '0',
        max: '30'
      },
      scale: {
        min: '0',
        max: '30'
      },
      unit: '1'
    }, {
      reserved: {},
      bitoffs: '16',
      bitsize: '2'
    }, {
      data: 'Meter 1 units',
      shortcut: 'UNIT1',
      description: 'Physical units of first measured quantity\n                  <br/>(imported value)',
      info: {},
      bitoffs: '18',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'No reading (unconfigured)',
          info: {}
        }, {
          value: '1',
          description: 'Current value W, accumulated value kWh'
        }, {
          value: '2',
          description: 'Current value W, accumulated value Wh'
        }, {
          value: '3',
          description: 'Accumulated value kWh only'
        }, {
          value: '4',
          description: 'Current value m3/h, accumulated value m3'
        }, {
          value: '5',
          description: 'Current value dm3/h, accumulated value dm3'
        }, {
          value: '6',
          description: 'Accumulated value m3 only'
        }, {
          value: '7',
          description: 'Digital counter'
        }]
      }
    }, {
      data: 'Meter 2 units',
      shortcut: 'UNIT2',
      description: 'Physical units of second measured quantity\n                  <br/>(exported value)',
      info: {},
      bitoffs: '21',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'No reading (unconfigured)',
          info: {}
        }, {
          value: '1',
          description: 'Current value W, accumulated value kWh'
        }, {
          value: '2',
          description: 'Current value W, accumulated value Wh'
        }, {
          value: '3',
          description: 'Accumulated value kWh only'
        }, {
          value: '4',
          description: 'Current value m3/h, accumulated value m3'
        }, {
          value: '5',
          description: 'Current value dm3/h, accumulated value dm3'
        }, {
          value: '6',
          description: 'Accumulated value m3 only'
        }, {
          value: '7',
          description: 'Digital counter'
        }]
      }
    }, {
      data: 'Factor of number of pulses',
      shortcut: 'FACP',
      description: 'The factor for the number of pulses\n                  <br/>per value in UNIT1',
      info: {},
      bitoffs: '24',
      bitsize: '2',
      enum: {
        item: [{
          value: '0',
          description: '1',
          info: {}
        }, {
          value: '1',
          description: '0.1'
        }, {
          value: '2',
          description: '0.01'
        }, {
          value: '3',
          description: '0.001'
        }]
      }
    }, {
      data: 'Number of pulses',
      shortcut: 'NOP',
      description: 'The number of pulses per value in UNIT1* FACP',
      info: {},
      bitoffs: '26',
      bitsize: '14',
      enum: {
        item: [{
          value: '0',
          description: 'Do not change the current setting of NOP',
          info: {}
        }, {
          min: '1',
          max: '16383',
          description: 'Number of pulses per unit<br/> (EEP 2.6.5:\n                    <span style="font-weight:bold;color:green">1 … 16383</span>\n                    <span style="text-decoration:line-through;color:red">1 … 65535</span>)'
        }]
      }
    }, {
      data: 'Preset value',
      shortcut: 'RST',
      description: 'Preset the accumulated value to this value',
      info: {},
      bitoffs: '40',
      bitsize: '32',
      enum: {
        item: [{
          min: '0',
          max: '4294967294',
          description: 'New preset value',
          info: {}
        }, {
          value: '0xFFFFFFFF',
          description: 'Do not change the current value'
        }]
      }
    }]
  }, {
    title: 'CMD 0x6 - Set meter configuration / D0 (BUS = 3)',
    description: {},
    datafield: [{
      data: 'Report measurement',
      shortcut: 'RM',
      description: 'Minimum auto reporting interval',
      info: {},
      bitoffs: '0',
      bitsize: '4',
      enum: {
        item: [{
          value: '0',
          description: 'No auto reporting',
          info: {}
        }, {
          value: '1',
          description: 'Min. 1 s interval'
        }, {
          value: '2',
          description: 'Min. 3 s interval'
        }, {
          value: '3',
          description: 'Min. 10 s interval'
        }, {
          value: '4',
          description: 'Min. 30 s interval'
        }, {
          value: '5',
          description: 'Min. 100 s interval'
        }, {
          value: '6',
          description: 'Min. 300 s interval'
        }, {
          value: '7',
          description: 'Min. 1000 s interval'
        }, {
          min: '8',
          max: '15',
          description: 'Reserved'
        }]
      }
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x06',
          description: 'ID 06'
        }
      }
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '1'
    }, {
      data: 'Meter bus type',
      shortcut: 'BUS',
      description: 'The meter bus that should be configured',
      info: {},
      bitoffs: '9',
      bitsize: '2',
      enum: {
        item: [{
          value: '0',
          description: 'Reserved',
          info: {}
        }, {
          value: '1',
          description: 'MBUS'
        }, {
          value: '2',
          description: 'S0'
        }, {
          value: '3',
          description: 'D0'
        }]
      }
    }, {
      data: 'Meter channel index',
      shortcut: 'MCH',
      description: 'The meter number of given bus that should be configured',
      info: {},
      bitoffs: '11',
      bitsize: '5',
      range: {
        min: '0',
        max: '30'
      },
      scale: {
        min: '0',
        max: '30'
      },
      unit: '1'
    }, {
      reserved: {},
      bitoffs: '16',
      bitsize: '2'
    }, {
      data: 'Meter 1 units',
      shortcut: 'UNIT1',
      description: 'Physical units of first measured quantity\n                  <br/>(imported value)',
      info: {},
      bitoffs: '18',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'No reading (unconfigured)',
          info: {}
        }, {
          value: '1',
          description: 'Current value W, accumulated value kWh'
        }, {
          value: '2',
          description: 'Current value W, accumulated value Wh'
        }, {
          value: '3',
          description: 'Accumulated value kWh only'
        }, {
          value: '4',
          description: 'Current value m3/h, accumulated value m3'
        }, {
          value: '5',
          description: 'Current value dm3/h, accumulated value dm3'
        }, {
          value: '6',
          description: 'Accumulated value m3 only'
        }, {
          value: '7',
          description: 'Digital counter'
        }]
      }
    }, {
      data: 'Meter 2 units',
      shortcut: 'UNIT2',
      description: 'Physical units of second measured quantity\n                  <br/>(exported value)',
      info: {},
      bitoffs: '21',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'No reading (unconfigured)',
          info: {}
        }, {
          value: '1',
          description: 'Current value W, accumulated value kWh'
        }, {
          value: '2',
          description: 'Current value W, accumulated value Wh'
        }, {
          value: '3',
          description: 'Accumulated value kWh only'
        }, {
          value: '4',
          description: 'Current value m3/h, accumulated value m3'
        }, {
          value: '5',
          description: 'Current value dm3/h, accumulated value dm3'
        }, {
          value: '6',
          description: 'Accumulated value m3 only'
        }, {
          value: '7',
          description: 'Digital counter'
        }]
      }
    }, {
      data: 'D0 Protocol',
      shortcut: 'PROT',
      description: 'The D0 protocol that should be used for that meter',
      info: {},
      bitoffs: '24',
      bitsize: '8',
      enum: {
        item: [{
          value: '0',
          description: 'Auto detect',
          info: {}
        }, {
          value: '1',
          description: 'SML (Smart Message Language)'
        }, {
          value: '2',
          description: 'DLMS (Device Language Message Specification)'
        }, {
          min: '3',
          max: '255',
          description: 'Reserved'
        }]
      }
    }, {
      reserved: {},
      bitoffs: '32',
      bitsize: '40'
    }]
  }, {
    title: 'CMD 0x7 - Meter Status Query',
    description: 'This message is sent to a metering device gateway to query the status of a meter.\n                <br/>Sender: controller; send type: broadcast or addressed; expected response: CMD 0x8.\n                <br/>',
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '4'
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x07',
          description: 'ID 07'
        }
      }
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '1'
    }, {
      data: 'Meter bus type',
      shortcut: 'BUS',
      description: 'The meter bus type that is queried',
      info: {},
      bitoffs: '9',
      bitsize: '2',
      enum: {
        item: [{
          value: '0',
          description: 'Reserved',
          info: {}
        }, {
          value: '1',
          description: 'MBUS'
        }, {
          value: '2',
          description: 'S0'
        }, {
          value: '3',
          description: 'D0'
        }]
      }
    }, {
      data: 'Meter channel index',
      shortcut: 'MCH',
      description: 'The meter channel of given bus that status is queried',
      info: {},
      bitoffs: '11',
      bitsize: '5',
      enum: {
        item: [{
          min: '0',
          max: '30',
          description: 'Meter channel',
          info: {}
        }, {
          value: '31',
          description: 'All valid channels'
        }]
      }
    }]
  }, {
    title: 'CMD 0x8 - Meter reading report / status response',
    description: 'This message is sent by a metering device gateway to report the meter\n              values for each configured channel.\n              It is sent if one of the following events occurs:\n                <br/>- Message "meter status query" has been received (CMD 0x7)\n                <br/>- Status or meter reading of one channel has changed and auto\n              reporting was configured by signal RM.\n                <br/>\n                <br/>Sender: sensor; send type: broadcast; maximum send delay 1 s.',
    datafield: [{
      reserved: {},
      bitoffs: '0',
      bitsize: '1'
    }, {
      data: 'Meter status / error',
      shortcut: 'MSTAT',
      description: 'Meter channel status',
      info: {},
      bitoffs: '1',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'No fault',
          info: {}
        }, {
          value: '1',
          description: 'General error'
        }, {
          value: '2',
          description: 'Bus unconfigured'
        }, {
          value: '3',
          description: 'Bus unconnected'
        }, {
          value: '4',
          description: 'Bus shortcut'
        }, {
          value: '5',
          description: 'Communication timeout'
        }, {
          value: '6',
          description: 'Unknown protocol or\n                      <br/>configuration mismatch'
        }, {
          value: '7',
          description: 'Bus initialization running'
        }]
      }
    }, {
      data: 'Command ID',
      shortcut: 'CMD',
      description: 'Command identifier',
      info: {},
      bitoffs: '4',
      bitsize: '4',
      enum: {
        item: {
          value: '0x08',
          description: 'ID 08'
        }
      }
    }, {
      reserved: {},
      bitoffs: '8',
      bitsize: '1'
    }, {
      data: 'Meter bus type',
      shortcut: 'BUS',
      description: 'The used bus of the meter status response',
      info: {},
      bitoffs: '9',
      bitsize: '2',
      enum: {
        item: [{
          value: '0',
          description: 'Reserved',
          info: {}
        }, {
          value: '1',
          description: 'MBUS'
        }, {
          value: '2',
          description: 'S0'
        }, {
          value: '3',
          description: 'D0'
        }]
      }
    }, {
      data: 'Meter channel index',
      shortcut: 'MCH',
      description: 'The meter number of given bus that status is reported',
      info: {},
      bitoffs: '11',
      bitsize: '5',
      range: {
        min: '0',
        max: '30'
      },
      scale: {
        min: '0',
        max: '30'
      },
      unit: '1'
    }, {
      reserved: {},
      bitoffs: '16',
      bitsize: '3'
    }, {
      data: 'Value selection',
      shortcut: 'VSEL',
      description: 'The selection of the reported value',
      info: {},
      bitoffs: '19',
      bitsize: '2',
      enum: {
        item: [{
          value: '0',
          description: 'Meter 1 Current value',
          info: {}
        }, {
          value: '1',
          description: 'Meter 1 Accumulated value'
        }, {
          value: '2',
          description: 'Meter 2 Current value'
        }, {
          value: '3',
          description: 'Meter 2 Accumulated value'
        }]
      }
    }, {
      data: 'Value unit',
      shortcut: 'VUNIT',
      description: 'The unit of the reported value',
      info: {},
      bitoffs: '21',
      bitsize: '3',
      enum: {
        item: [{
          value: '0',
          description: 'W',
          info: {}
        }, {
          value: '1',
          description: 'Wh'
        }, {
          value: '2',
          description: 'kWh'
        }, {
          value: '3',
          description: 'm3/h'
        }, {
          value: '4',
          description: 'dm3/h'
        }, {
          value: '5',
          description: 'm3'
        }, {
          value: '6',
          description: 'dm3'
        }, {
          value: '7',
          description: '1 (digital counter)'
        }]
      }
    }, {
      data: 'Meter reading value',
      shortcut: 'VAL',
      description: 'The reported value',
      info: {},
      bitoffs: '24',
      bitsize: '32',
      range: {
        min: '0',
        max: '4294967295'
      },
      scale: {
        min: '0',
        max: '4294967295'
      },
      unit: 'According to VUNIT'
    }]
  }],
  originalIndex: 197,
  eep: 'd2-30-00',
  rorg_title: 'VLD Telegram',
  rorg_number: '0xD2',
  func_title: 'Floor Heating Controls and Automated Meter Reading',
  func_number: '0x30',
  submitter: [
    'MSR-Solutions'
  ]
}
